==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_viewport.js <==
var class_ogre_1_1_viewport =
[
    [ "Listener", "class_ogre_1_1_viewport_1_1_listener.html", "class_ogre_1_1_viewport_1_1_listener" ],
    [ "Viewport", "class_ogre_1_1_viewport.html#aed9de01a3a183ffec5c6d63c1335e239", null ],
    [ "~Viewport", "class_ogre_1_1_viewport.html#a7b76633e02431bd4254f6d4629b7672a", null ],
    [ "_updateDimensions", "class_ogre_1_1_viewport.html#a23c2b69bbc3d76fd52a4729a71caed08", null ],
    [ "update", "class_ogre_1_1_viewport.html#ab281517fd8070ab1617f126b752bb025", null ],
    [ "clear", "class_ogre_1_1_viewport.html#ad725dbbd3c4e48c81549a4daffad0484", null ],
    [ "getTarget", "class_ogre_1_1_viewport.html#a8ee40d36b872427b77e80be8aaf6f17b", null ],
    [ "getCamera", "class_ogre_1_1_viewport.html#a114f0cb15aeef60d28d2e7879d35239c", null ],
    [ "setCamera", "class_ogre_1_1_viewport.html#a20aa22b47f03e523aaeb0d54e094fbf3", null ],
    [ "getZOrder", "class_ogre_1_1_viewport.html#adef304662a6b751004a801d64e3cbcbe", null ],
    [ "getLeft", "class_ogre_1_1_viewport.html#abacd2b3e5d30e5ebd043c81485ef4424", null ],
    [ "getTop", "class_ogre_1_1_viewport.html#aee1005abbba241606e7d295b46d637d4", null ],
    [ "getWidth", "class_ogre_1_1_viewport.html#ab63ef4a61e6af6074cd28fd05774ff2c", null ],
    [ "getHeight", "class_ogre_1_1_viewport.html#a2a942db10f2d284830828bbc03cc80b7", null ],
    [ "getActualLeft", "class_ogre_1_1_viewport.html#a48a8851cd964559ac62100ef9fda8297", null ],
    [ "getActualTop", "class_ogre_1_1_viewport.html#a80f20023a3c8a8abacb4d4d989a52783", null ],
    [ "getActualWidth", "class_ogre_1_1_viewport.html#a4ee7260b460f6d8305dbb85dea34f8bf", null ],
    [ "getActualHeight", "class_ogre_1_1_viewport.html#ac7313a454230df06a95bef8421c97919", null ],
    [ "setDimensions", "class_ogre_1_1_viewport.html#ab62df3fb040cf9db8c00b54b8ba614d6", null ],
    [ "setOrientationMode", "class_ogre_1_1_viewport.html#a10c41ba5b52fce35e3c2df7b6b38477b", null ],
    [ "getOrientationMode", "class_ogre_1_1_viewport.html#a9d504d935b3de2f7ff9da03adb272cc3", null ],
    [ "setDefaultOrientationMode", "class_ogre_1_1_viewport.html#a05cec59a7c2ee14e97ad468f42d21661", null ],
    [ "getDefaultOrientationMode", "class_ogre_1_1_viewport.html#ae7d0d74c7a7c17a7b94e44b3fb481030", null ],
    [ "setBackgroundColour", "class_ogre_1_1_viewport.html#a3770973e7626d75592a79d0670b862d9", null ],
    [ "getBackgroundColour", "class_ogre_1_1_viewport.html#a5f5020c780760838013c7d3b1549d39a", null ],
    [ "setDepthClear", "class_ogre_1_1_viewport.html#afc3cf379272926fa22b0e7cfd04445a9", null ],
    [ "getDepthClear", "class_ogre_1_1_viewport.html#a4d2598f85e084bdd48948b78563a178d", null ],
    [ "setClearEveryFrame", "class_ogre_1_1_viewport.html#ad9c172c23b0dcccd929f31d4416f9683", null ],
    [ "getClearEveryFrame", "class_ogre_1_1_viewport.html#aa4d95fd3c06e7bfeee05eda6ffe00bf2", null ],
    [ "getClearBuffers", "class_ogre_1_1_viewport.html#a4990f072113220a9fd2e14dc78b24638", null ],
    [ "setAutoUpdated", "class_ogre_1_1_viewport.html#a6fa1ca3a866134b2e8ef06749cbddba8", null ],
    [ "isAutoUpdated", "class_ogre_1_1_viewport.html#a4236ea24b392c4b45a8233911ec9291d", null ],
    [ "setMaterialScheme", "class_ogre_1_1_viewport.html#a8e8577fd81c45b05de880106f364a281", null ],
    [ "getMaterialScheme", "class_ogre_1_1_viewport.html#ae26d5c714d1527f8e51a8c60e591747c", null ],
    [ "getActualDimensions", "class_ogre_1_1_viewport.html#a035b2d7991af956b7e1492541b6ea671", null ],
    [ "getActualDimensions", "class_ogre_1_1_viewport.html#a7fb7b0cdc841b05a89977a50d3336fa3", null ],
    [ "_isUpdated", "class_ogre_1_1_viewport.html#a17077d89f82a12c18bb40858ce302aa0", null ],
    [ "_clearUpdatedFlag", "class_ogre_1_1_viewport.html#a7998e64f3a79ac014813218f5e7cdd8e", null ],
    [ "_getNumRenderedFaces", "class_ogre_1_1_viewport.html#add935b437a724d28502ada8f45de4c42", null ],
    [ "_getNumRenderedBatches", "class_ogre_1_1_viewport.html#a35036263788bbbe95a05621c39fdd5ef", null ],
    [ "setOverlaysEnabled", "class_ogre_1_1_viewport.html#a598f5bd68b1c88cd3ae5a50343965afd", null ],
    [ "getOverlaysEnabled", "class_ogre_1_1_viewport.html#a4982331a28558dcaf4d25822857655f2", null ],
    [ "setSkiesEnabled", "class_ogre_1_1_viewport.html#a176a24ccbb9881c4fc61f3f1aaba3c12", null ],
    [ "getSkiesEnabled", "class_ogre_1_1_viewport.html#a66b9f819dded193d961d505e589da998", null ],
    [ "setShadowsEnabled", "class_ogre_1_1_viewport.html#ab71a4790d66e3cddd3b36b3c1b4fd23c", null ],
    [ "getShadowsEnabled", "class_ogre_1_1_viewport.html#abefe1016cbc08cc395d46822b4e22ade", null ],
    [ "setVisibilityMask", "class_ogre_1_1_viewport.html#ad5a4fe00ee05861c157bf63e78e1c2b0", null ],
    [ "getVisibilityMask", "class_ogre_1_1_viewport.html#a48fec9ee9f90672adbc37dca7ef55a64", null ],
    [ "pointOrientedToScreen", "class_ogre_1_1_viewport.html#a40e29f3225c47bea22822274d4d021eb", null ],
    [ "pointOrientedToScreen", "class_ogre_1_1_viewport.html#a4e34363fb51b8b3380981694b42c77e7", null ],
    [ "addListener", "class_ogre_1_1_viewport.html#ac0f6279cc741ced692f2533f280f04d0", null ],
    [ "removeListener", "class_ogre_1_1_viewport.html#a931d07d2aea40d67f5f6addc5a33feaf", null ],
    [ "setDrawBuffer", "class_ogre_1_1_viewport.html#a7d96a62ee1b17926cebda70f96adc72f", null ],
    [ "getDrawBuffer", "class_ogre_1_1_viewport.html#a37c0cea85d6d124a70cf6cd575647638", null ]
];

==> ogre-14.5.2-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_viewport.js <==
var class_ogre_1_1_viewport =
[
    [ "Listener", "class_ogre_1_1_viewport_1_1_listener.html", "class_ogre_1_1_viewport_1_1_listener" ],
    [ "Viewport", "class_ogre_1_1_viewport.html#aed9de01a3a183ffec5c6d63c1335e239", null ],
    [ "Viewport", "class_ogre_1_1_viewport.html#ae315ad62d7533db531e6ada591bfcc45", null ],
    [ "~Viewport", "class_ogre_1_1_viewport.html#a7b76633e02431bd4254f6d4629b7672a", null ],
    [ "_updateDimensions", "class_ogre_1_1_viewport.html#a23c2b69bbc3d76fd52a4729a71caed08", null ],
    [ "update", "class_ogre_1_1_viewport.html#ab281517fd8070ab1617f126b752bb025", null ],
    [ "clear", "class_ogre_1_1_viewport.html#ad725dbbd3c4e48c81549a4daffad0484", null ],
    [ "getTarget", "class_ogre_1_1_viewport.html#a8ee40d36b872427b77e80be8aaf6f17b", null ],
    [ "getCamera", "class_ogre_1_1_viewport.html#a114f0cb15aeef60d28d2e7879d35239c", null ],
    [ "setCamera", "class_ogre_1_1_viewport.html#a20aa22b47f03e523aaeb0d54e094fbf3", null ],
    [ "getZOrder", "class_ogre_1_1_viewport.html#adef304662a6b751004a801d64e3cbcbe", null ],
    [ "getLeft", "class_ogre_1_1_viewport.html#abacd2b3e5d30e5ebd043c81485ef4424", null ],
    [ "getTop", "class_ogre_1_1_viewport.html#aee1005abbba241606e7d295b46d637d4", null ],
    [ "getWidth", "class_ogre_1_1_viewport.html#ab63ef4a61e6af6074cd28fd05774ff2c", null ],
    [ "getHeight", "class_ogre_1_1_viewport.html#a2a942db10f2d284830828bbc03cc80b7", null ],
    [ "getDimensions", "class_ogre_1_1_viewport.html#add9306326dea27250afd3cc128af415c", null ],
    [ "setDimensions", "class_ogre_1_1_viewport.html#ab62df3fb040cf9db8c00b54b8ba614d6", null ],
    [ "getActualLeft", "class_ogre_1_1_viewport.html#a48a8851cd964559ac62100ef9fda8297", null ],
    [ "getActualTop", "class_ogre_1_1_viewport.html#a80f20023a3c8a8abacb4d4d989a52783", null ],
    [ "getActualWidth", "class_ogre_1_1_viewport.html#a4ee7260b460f6d8305dbb85dea34f8bf", null ],
    [ "getActualHeight", "class_ogre_1_1_viewport.html#ac7313a454230df06a95bef8421c97919", null ],
    [ "getActualDimensions", "class_ogre_1_1_viewport.html#a035b2d7991af956b7e1492541b6ea671", null ],
    [ "setBackgroundColour", "class_ogre_1_1_viewport.html#a3770973e7626d75592a79d0670b862d9", null ],
    [ "getBackgroundColour", "class_ogre_1_1_viewport.html#a5f5020c780760838013c7d3b1549d39a", null ],
    [ "setDepthClear", "class_ogre_1_1_viewport.html#afc3cf379272926fa22b0e7cfd04445a9", null ],
    [ "getDepthClear", "class_ogre_1_1_viewport.html#a4d2598f85e084bdd48948b78563a178d", null ],
    [ "setClearEveryFrame", "class_ogre_1_1_viewport.html#ad9c172c23b0dcccd929f31d4416f9683", null ],
    [ "getClearEveryFrame", "class_ogre_1_1_viewport.html#aa4d95fd3c06e7bfeee05eda6ffe00bf2", null ],
    [ "getClearBuffers", "class_ogre_1_1_viewport.html#a4990f072113220a9fd2e14dc78b24638", null ],
    [ "setAutoUpdated", "class_ogre_1_1_viewport.html#a6fa1ca3a866134b2e8ef06749cbddba8", null ],
    [ "isAutoUpdated", "class_ogre_1_1_viewport.html#a4236ea24b392c4b45a8233911ec9291d", null ],
    [ "setMaterialScheme", "class_ogre_1_1_viewport.html#a8e8577fd81c45b05de880106f364a281", null ],
    [ "getMaterialScheme", "class_ogre_1_1_viewport.html#ae26d5c714d1527f8e51a8c60e591747c", null ],
    [ "getActualDimensions", "class_ogre_1_1_viewport.html#a7fb7b0cdc841b05a89977a50d3336fa3", null ],
    [ "_isUpdated", "class_ogre_1_1_viewport.html#a17077d89f82a12c18bb40858ce302aa0", null ],
    [ "_clearUpdatedFlag", "class_ogre_1_1_viewport.html#a7998e64f3a79ac014813218f5e7cdd8e", null ],
    [ "_getNumRenderedFaces", "class_ogre_1_1_viewport.html#add935b437a724d28502ada8f45de4c42", null ],
    [ "_getNumRenderedBatches", "class_ogre_1_1_viewport.html#a35036263788bbbe95a05621c39fdd5ef", null ],
    [ "setOverlaysEnabled", "class_ogre_1_1_viewport.html#a598f5bd68b1c88cd3ae5a50343965afd", null ],
    [ "getOverlaysEnabled", "class_ogre_1_1_viewport.html#a4982331a28558dcaf4d25822857655f2", null ],
    [ "setSkiesEnabled", "class_ogre_1_1_viewport.html#a176a24ccbb9881c4fc61f3f1aaba3c12", null ],
    [ "getSkiesEnabled", "class_ogre_1_1_viewport.html#a66b9f819dded193d961d505e589da998", null ],
    [ "setShadowsEnabled", "class_ogre_1_1_viewport.html#ab71a4790d66e3cddd3b36b3c1b4fd23c", null ],
    [ "getShadowsEnabled", "class_ogre_1_1_viewport.html#abefe1016cbc08cc395d46822b4e22ade", null ],
    [ "setVisibilityMask", "class_ogre_1_1_viewport.html#ad5a4fe00ee05861c157bf63e78e1c2b0", null ],
    [ "getVisibilityMask", "class_ogre_1_1_viewport.html#a48fec9ee9f90672adbc37dca7ef55a64", null ],
    [ "addListener", "class_ogre_1_1_viewport.html#ac0f6279cc741ced692f2533f280f04d0", null ],
    [ "removeListener", "class_ogre_1_1_viewport.html#a931d07d2aea40d67f5f6addc5a33feaf", null ],
    [ "setDrawBuffer", "class_ogre_1_1_viewport.html#a7d96a62ee1b17926cebda70f96adc72f", null ],
    [ "getDrawBuffer", "class_ogre_1_1_viewport.html#a37c0cea85d6d124a70cf6cd575647638", null ]
];
